@@ -71,3 +71,24 @@ class SQL_Select():
   froms: Union[SQL_JoinExpression, List[SQL_SelectFrom]]
   where: SQL_BinaryExpression
   
+@dataclass
+class SQL_Update():
+  type='update'
+  table: SQL_SelectFrom
+  sets: List[SQL_BinaryExpression]
+  where: SQL_BinaryExpression
+
+@dataclass
+class SQL_Insert():
+  type='insert'
+  table: SQL_SelectFrom
+  columns: List[SQL_ColumnRef]
+  values: SQL_ValueList
+
+@dataclass
+class SQL_Delete():
+  type='delete'
+  table: SQL_SelectFrom
+  where: SQL_BinaryExpression
+
+SQL_DML_Command = Union[SQL_Select, SQL_Insert, SQL_Update, SQL_Delete]
